==> colby-bootstrap-1.0.18.tgz: package/wp-autoload/shortcodes/whats-new.php <==
<?php

function render_category_select( $categories, $atts ) {
	if ( $categories === null || ! $atts['news-page'] ) {
		return '';
	}

	echo "<form action={$atts['news-page']}><select name=category onchange=\"this.form.submit()\">";
	echo "<option>CATEGORY</option>";

	foreach ( $categories as $category ) {
		echo "<option value=\"{$category->slug}\">{$category->name}</option>";
	}

	echo "</select></form>";
}


function render_whats_new( $the_post, $categories, $atts = [] ) {
	global $post;

	$post = $the_post;
	ob_start();

	setup_postdata( $post );
	?>
<aside class=StickyPostPreview>
	<?php if ( $atts['title'] ) : ?>
	<div class="stickyPost__header">
		<button class="badge"><?php echo $atts['title']; ?></button>
		<?php echo render_category_select( $categories, $atts ); ?>
	</div>
	<?php endif; ?>
	<div class="stickyPost__body">
		<div class="stickyPost__body-header">
			<h1>
			  <a href=<?php the_permalink(); ?>>
				  <?php the_title(); ?>
			  </a>
		  </h1>
		    <time dateTime="<?php echo $sticky->post_date; ?>">
		      <?php the_date(); ?>
		    </time>
		</div>
		<div>
	    <?php if ( $atts['excerpt'] ) :
			echo '<p>' . get_the_excerpt() . '</p>';
		else :
			echo wpautop( get_the_content() );
		endif;
		?><?php if ( $atts['excerpt'] ) : ?> <a class="display-3" href=<?php the_permalink() ?>>
	      Continue reading
	    </a>
		<?php endif; ?>
		</div>
	</div>
</aside>

	<?php

	wp_reset_postdata();
	return ob_get_clean();
}


function init_whats_new_shortcode() {
	add_shortcode( 'whats-new', function( $atts ) {
		$sticky = get_option( 'sticky_posts' );

		$args = [
			'posts_per_page' => 1,
			'post_type' => 'post'
		];

		if ( $sticky ) {
			$args['p'] = $sticky[0];
		}

		$query = new WP_Query( $args );

		if ( ! $query->posts ) {
			return '';
		}

		$categories = $atts['category-select'] ? get_categories( [
			'hide_empty' => true,
			'exclude' => 1
		] ) : null;

		return render_whats_new( $query->posts[0], $categories, $atts );
	} );
}

add_action( 'init', 'init_whats_new_shortcode' );

==> colby-bootstrap-1.0.45.tgz: package/wp-autoload/shortcodes/whats-new.php <==
<?php

function render_category_select( $categories, $atts ) {
	if ( $categories === null || ! $atts['news-page'] ) {
		return '';
	}

	echo "<form action={$atts['news-page']}><select name=category onchange=\"this.form.submit()\">";
	echo "<option>CATEGORY</option>";

	foreach ( $categories as $category ) {
		echo "<option value=\"{$category->slug}\">{$category->name}</option>";
	}

	echo "</select></form>";
}


function render_whats_new( $the_post, $categories, $atts = [] ) {
	global $post;

	$post = $the_post;
	ob_start();

	setup_postdata( $post );
	?>
<aside class=StickyPostPreview>
	<?php if ( $atts['title'] ) : ?>
	<div class="stickyPost__header">
		<button class="badge"><?php echo $atts['title']; ?></button>
		<?php echo render_category_select( $categories, $atts ); ?>
	</div>
	<?php endif; ?>
	<div class="stickyPost__body">
		<div class="stickyPost__body-header">
			<h1>
			  <a href=<?php the_permalink(); ?>>
				  <?php the_title(); ?>
			  </a>
		  </h1>
		    <time dateTime="<?php echo $post->post_date; ?>">
		      <?php the_date(); ?>
		    </time>
		</div>
		<div>
	    <?php if ( $atts['excerpt'] ) :
			echo '<p>' . get_the_excerpt() . '</p>';
		else :
			echo wpautop( get_the_content() );
		endif;
		?><?php if ( $atts['excerpt'] ) : ?> <a class="display-3" href=<?php the_permalink() ?>>
	      Continue reading
	    </a>
		<?php endif; ?>
		</div>
	</div>
</aside>

	<?php

	wp_reset_postdata();
	return ob_get_clean();
}


function init_whats_new_shortcode() {
	add_shortcode( 'whats-new', function( $atts ) {

		$args = [
			'posts_per_page' => 1,
			'post_type' => 'post'
		];

		if ( ! empty( $atts['sticky'] ) ) {
			$sticky = get_option( 'sticky_posts' );
			if ( $sticky ) {
				$args['p'] = $sticky[0];
			}
		}

		$query = new WP_Query( $args );

		if ( ! $query->posts ) {
			return '';
		}

		$categories = $atts['category-select'] ? get_categories( [
			'hide_empty' => true,
			'exclude' => 1
		] ) : null;

		return render_whats_new( $query->posts[0], $categories, $atts );
	} );
}

add_action( 'init', 'init_whats_new_shortcode' );
